@@ -10,13 +10,6 @@ from typing import Optional
 from .config import Config
 from .client import RelayClient
 from .hooks import HooksInstaller
-from .cloudkit_client import (
-    CloudKitClient,
-    CloudKitError,
-    CloudKitNotConfigured,
-    CloudKitUnavailable,
-    DeviceNotFound,
-)
 
 
 def install_scripts() -> dict:
@@ -105,80 +98,6 @@ def main():
     pass
 
 
-def _setup_with_cloudkit(config: Config) -> Optional[str]:
-    """Attempt to set up using CloudKit prefix lookup.
-
-    Returns:
-        The auth token if successful, None if user wants manual entry.
-    """
-    # Check if CloudKit is available and configured
-    if not CloudKitClient.is_available():
-        click.echo("CloudKit client not available (missing dependencies).")
-        click.echo("Falling back to manual setup.")
-        click.echo()
-        return None
-
-    if not CloudKitClient.is_configured():
-        # This is expected for most users - CloudKit bridge is optional
-        return None
-
-    click.echo("CloudKit bridge available - simplified setup enabled!")
-    click.echo()
-    click.echo("Enter the first 4 characters of your setup code.")
-    click.echo("(The full code is shown on your Watch in Settings)")
-    click.echo()
-
-    client = CloudKitClient()
-    max_attempts = 3
-
-    for attempt in range(max_attempts):
-        prefix = click.prompt("Setup code prefix (4 characters)", type=str).strip().upper()
-
-        # Validate prefix format
-        if len(prefix) != 4 or not prefix.isalnum():
-            click.echo("Invalid prefix. Enter exactly 4 alphanumeric characters.")
-            continue
-
-        click.echo(f"Looking up device with prefix '{prefix}'...")
-
-        try:
-            auth_token, device_token = client.find_device_by_prefix(prefix)
-
-            click.echo()
-            click.echo(f"Found device: {config.format_token_display(auth_token)}")
-            click.echo()
-
-            # Confirm with user
-            if click.confirm("Is this your device?", default=True):
-                return auth_token
-            else:
-                click.echo("Try entering the prefix again or use --manual for full code entry.")
-
-        except DeviceNotFound as e:
-            click.echo(f"Not found: {e}")
-            if attempt < max_attempts - 1:
-                click.echo("Try again or use 'watchcode setup --manual' for full code entry.")
-            else:
-                click.echo()
-                click.echo("Could not find device after multiple attempts.")
-                if click.confirm("Switch to manual entry?", default=True):
-                    return None
-                else:
-                    return None  # Exit setup
-
-        except CloudKitUnavailable as e:
-            click.echo(f"CloudKit unavailable: {e}")
-            click.echo("Falling back to manual setup.")
-            return None
-
-        except CloudKitError as e:
-            click.echo(f"CloudKit error: {e}")
-            click.echo("Falling back to manual setup.")
-            return None
-
-    return None
-
-
 def _setup_manual(config: Config) -> str:
     """Manual setup with full 12-character code entry.
 
@@ -205,13 +124,8 @@ def _setup_manual(config: Config) -> str:
 
 
 @main.command()
-@click.option("--manual", is_flag=True, help="Use manual 12-character code entry instead of CloudKit lookup")
-def setup(manual: bool):
-    """Interactive setup - configure WatchCode with your setup code.
-
-    By default, uses CloudKit to lookup your device with just 4 characters.
-    Use --manual to enter the full 12-character code.
-    """
+def setup():
+    """Interactive setup - configure WatchCode with your setup code."""
     config = Config()
     installer = HooksInstaller()
 
@@ -243,15 +157,8 @@ def setup(manual: bool):
             click.echo(f"  Fixed: {', '.join(cleanup_result['fixed'])}")
         click.echo()
 
-    # Attempt CloudKit setup first (unless --manual specified)
-    clean_token = None
-
-    if not manual:
-        clean_token = _setup_with_cloudkit(config)
-
-    # Fall back to manual if CloudKit didn't work
-    if clean_token is None:
-        clean_token = _setup_manual(config)
+    # Get setup code from user
+    clean_token = _setup_manual(config)
 
     # Save auth token
     config.set_auth_token(clean_token)
