@@ -675,22 +675,18 @@ def handle_notification(data: dict) -> int:
         notification_id=notification_id
     )
 
-    # Output decision via JSON AND keyboard injection
-    # Claude Code uses hookSpecificOutput JSON, but also shows interactive prompt
-    # Keyboard injection ensures the response works even if stdout isn't monitored
+    # Output decision via JSON only (no keystroke injection for permission_request)
+    # Claude Code reads hookSpecificOutput JSON - keystroke injection caused double input
     if response:
         action = response.get('action', '').lower()
         if action == 'approve':
             output_decision('allow')
-            inject_keystroke('1')  # 1 = Allow
             log_debug(f"[seq={sequence_id}] User APPROVED via Watch")
         elif action == 'deny':
             output_decision('deny', 'Denied via Apple Watch')
-            inject_keystroke('3')  # 3 = Deny
             log_debug(f"[seq={sequence_id}] User DENIED via Watch")
         elif action == 'always_allow':
             output_decision('allow')  # JSON doesn't have "always allow" option
-            inject_keystroke('2')  # 2 = Always Allow
             log_debug(f"[seq={sequence_id}] User set ALWAYS ALLOW via Watch")
     else:
         log_debug(f"[seq={sequence_id}] No response, falling back to terminal")
